@@ -1,12 +1,15 @@
 use strict;
 use warnings;
-package App::Nopaste; # git description: 1.003-10-gd281f41
+package App::Nopaste; # git description: 1.005-10-g54f7c2d
 # ABSTRACT: Easy access to any pastebin
-our $VERSION = '1.004';
+# KEYWORDS: application executable paste output pastebin debugging
+
+our $VERSION = '1.006';
+
 use 5.008003;
 use Module::Pluggable search_path => 'App::Nopaste::Service', sub_name => '_plugins';
 use Class::Load 'load_class';
-use namespace::clean;
+use namespace::clean 0.19;
 
 use base 'Exporter';
 our @EXPORT_OK = 'nopaste';
@@ -98,7 +101,7 @@ App::Nopaste - Easy access to any pastebin
 
 =head1 VERSION
 
-version 1.004
+version 1.006
 
 =head1 SYNOPSIS
 
@@ -189,20 +192,18 @@ Copyright 2008- Shawn M Moore.
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=App-Nopaste>
+(or L<bug-App-Nopaste@rt.cpan.org|mailto:bug-App-Nopaste@rt.cpan.org>).
+
 =head1 AUTHOR
 
 Shawn M Moore, <sartak@gmail.com>
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2008 by Shawn M Moore.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 CONTRIBUTORS
 
-=for stopwords Shawn M Moore Karen Etheridge Thomas Sibley François Gannaz Ricardo Signes Justin Hunter Kevin Falcone Zoffix Znet David Golden Dean Hamstead Sergey Romanov Jesse Luehrs Rafael Kitover Arthur Axel 'fREW' Schmidt יובל קוג'מן (Yuval Kogman) Darian Anthony Patrick Bremner Graham Knop Jason Mills John Goulah Maximilian Gass Sebastian Paaske Tørholm Tatsuhiko Miyagawa gregor herrmann vti Ævar Arnfjörð Bjarmason Сергей Романов
+=for stopwords Shawn M Moore Karen Etheridge Thomas Sibley François Gannaz Ricardo Signes Justin Hunter Kevin Falcone Zoffix Znet David Golden Dean Hamstead Sergey Romanov Jesse Luehrs Rafael Kitover Сергей Романов Arthur Axel 'fREW' Schmidt יובל קוג'מן (Yuval Kogman) Darian Anthony Patrick Bremner J. Shultz Graham Knop Jason Mills John Goulah Maximilian Gass Sebastian Paaske Tørholm Tatsuhiko Miyagawa gregor herrmann vti Ævar Arnfjörð Bjarmason
 
 =over 4
 
@@ -260,6 +261,10 @@ Rafael Kitover <rkitover@cpan.org>
 
 =item *
 
+Сергей Романов <sromanov@cpan.org>
+
+=item *
+
 Arthur Axel 'fREW' Schmidt <frioux@gmail.com>
 
 =item *
@@ -276,6 +281,10 @@ David Bremner <bremner@unb.ca>
 
 =item *
 
+David J. Shultz <djshultz@gmail.com>
+
+=item *
+
 Graham Knop <haarg@haarg.org>
 
 =item *
@@ -310,10 +319,13 @@ vti <viacheslav.t@gmail.com>
 
 Ævar Arnfjörð Bjarmason <avarab@gmail.com>
 
-=item *
-
-Сергей Романов <sromanov@cpan.org>
-
 =back
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2008 by Shawn M Moore.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
