@@ -1,10 +1,10 @@
 use strict;
 use warnings;
 package App::Nopaste::Service::Codepeek;
-BEGIN {
-  $App::Nopaste::Service::Codepeek::AUTHORITY = 'cpan:SARTAK';
-}
-$App::Nopaste::Service::Codepeek::VERSION = '0.96';
+# ABSTRACT: (DEPRECATED) Service for Codepeek - http://codepeek.com
+
+our $VERSION = '1.006';
+
 use base 'App::Nopaste::Service';
 
 sub uri { 'http://codepeek.com/paste' }
@@ -36,20 +36,43 @@ sub return {
 }
 
 1;
+
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-App::Nopaste::Service::Codepeek - http://codepeek.com
+App::Nopaste::Service::Codepeek - (DEPRECATED) Service for Codepeek - http://codepeek.com
 
 =head1 VERSION
 
-version 0.96
+version 1.006
+
+=head1 DEPRECATION NOTICE
+
+L<http://codepeek.com> is now offline, so this service no longer works.
 
 =head1 AUTHOR
 
 Justin Hunter, C<< <justin.d.hunter@gmail.com> >>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=App-Nopaste>
+(or L<bug-App-Nopaste@rt.cpan.org|mailto:bug-App-Nopaste@rt.cpan.org>).
+
+=head1 AUTHOR
+
+Shawn M Moore, <sartak@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2008 by Shawn M Moore.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
