@@ -2,10 +2,12 @@ use strict;
 use warnings;
 package App::Nopaste::Service::PastebinCom;
 # ABSTRACT: Service provider for Pastebin - http://pastebin.com/
-our $VERSION = '1.004';
+
+our $VERSION = '1.006';
+
 use base 'App::Nopaste::Service';
 use Module::Runtime 'use_module';
-use namespace::clean;
+use namespace::clean 0.19;
 
 sub available {
     eval { use_module('WWW::Pastebin::PastebinCom::Create'); 1 }
@@ -46,12 +48,17 @@ App::Nopaste::Service::PastebinCom - Service provider for Pastebin - http://past
 
 =head1 VERSION
 
-version 1.004
+version 1.006
 
 =head1 SEE ALSO
 
 L<WWW::Pastebin::PastebinCom::Create>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=App-Nopaste>
+(or L<bug-App-Nopaste@rt.cpan.org|mailto:bug-App-Nopaste@rt.cpan.org>).
+
 =head1 AUTHOR
 
 Shawn M Moore, <sartak@gmail.com>
