@@ -2,7 +2,9 @@ use strict;
 use warnings;
 package App::Nopaste::Service::Shadowcat;
 # ABSTRACT: Service provider for Shadowcat - http://paste.scsys.co.uk/
-our $VERSION = '1.004';
+
+our $VERSION = '1.006';
+
 use base 'App::Nopaste::Service';
 
 sub available {
@@ -27,7 +29,12 @@ App::Nopaste::Service::Shadowcat - Service provider for Shadowcat - http://paste
 
 =head1 VERSION
 
-version 1.004
+version 1.006
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=App-Nopaste>
+(or L<bug-App-Nopaste@rt.cpan.org|mailto:bug-App-Nopaste@rt.cpan.org>).
 
 =head1 AUTHOR
 
