@@ -2,7 +2,9 @@ use strict;
 use warnings;
 package App::Nopaste::Service::Ubuntu;
 # ABSTRACT: Service provider for Ubuntu - http://paste.ubuntu.com/
-our $VERSION = '1.004';
+
+our $VERSION = '1.006';
+
 use base 'App::Nopaste::Service';
 
 my $languages = {
@@ -246,7 +248,7 @@ App::Nopaste::Service::Ubuntu - Service provider for Ubuntu - http://paste.ubunt
 
 =head1 VERSION
 
-version 1.004
+version 1.006
 
 =for stopwords Niebur
 
@@ -257,6 +259,11 @@ gregor herrmann, C<< <gregoa@debian.org> >>
 (Based on App::Nopaste::Service::Debian, written by
 Ryan Niebur, C<< <ryanryan52@gmail.com> >>)
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=App-Nopaste>
+(or L<bug-App-Nopaste@rt.cpan.org|mailto:bug-App-Nopaste@rt.cpan.org>).
+
 =head1 AUTHOR
 
 Shawn M Moore, <sartak@gmail.com>
