@@ -2,13 +2,15 @@ use strict;
 use warnings;
 package App::Nopaste::Service::ssh;
 # ABSTRACT: Copies files to your server using scp
-our $VERSION = '1.004';
+
+our $VERSION = '1.006';
+
 use base 'App::Nopaste::Service';
 use File::Temp;
 use File::Spec;
 use POSIX qw(strftime);
 use URI::Escape qw(uri_escape);
-use namespace::clean;
+use namespace::clean 0.19;
 
 sub run {
     my ($self, %args) = @_;
@@ -75,7 +77,7 @@ App::Nopaste::Service::ssh - Copies files to your server using scp
 
 =head1 VERSION
 
-version 1.004
+version 1.006
 
 =for stopwords dir
 
@@ -129,6 +131,11 @@ Kevin Falcone C<< <falcone@cpan.org> >>
 
 Thomas Sibley C<< <trs@bestpractical.com> >>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=App-Nopaste>
+(or L<bug-App-Nopaste@rt.cpan.org|mailto:bug-App-Nopaste@rt.cpan.org>).
+
 =head1 AUTHOR
 
 Shawn M Moore, <sartak@gmail.com>
